@@ -2,7 +2,7 @@
 #'
 #' remoteDriver Class uses the JsonWireProtocol to communicate with the
 #'    Selenium Server. If an error occurs while executing the command then
-#'    the server sends back an HTTP error code with a JSON encoded reponse
+#'    the server sends back an HTTP error code with a JSON encoded response
 #'    that indicates the precise Response Error Code. The remoteDriver
 #'    class inherits from the \code{errorHandler} class. If no error
 #'    occurred, then the subroutine called will return the value sent back
@@ -82,11 +82,13 @@
 #'
 #' # The R homepage contains frames
 #' webElem <- remDr$findElements(value = "//frame")
-#' sapply(webElem, function(x) {x$getElementAttribute('name')})
+#' sapply(webElem, function(x) {
+#'   x$getElementAttribute("name")
+#' })
 #'
 #' # The homepage contains 3 frames: logo, contents and banner
 #' # switch to the `contents` frame
-#' webElem <- remDr$findElement(using = 'name', value = 'contents')
+#' webElem <- remDr$findElement(using = "name", value = "contents")
 #' remDr$switchToFrame(webElem$elementId)
 #'
 #' # re-examine the page source
@@ -96,7 +98,7 @@
 #'
 #' # Find the link for the search page on R homepage. Use xpath as default.
 #' webElem <- remDr$findElement(value = '//a[@@href = "search.html"]')
-#' webElem$getElementAttribute('href')
+#' webElem$getElementAttribute("href")
 #' # http://www.r-project.org/search.html
 #'
 #' # click the search link
@@ -107,23 +109,26 @@
 #'
 #' # show different methods of accessing DOM components
 #'
-#' webElem1 <- remDr$findElement(using = 'name', value = 'q')
+#' webElem1 <- remDr$findElement(using = "name", value = "q")
 #' webElem2 <- remDr$findElement(
-#'   using = 'id',
-#'   value = webElem1$getElementAttribute('id')[[1]])
-#' webElem3 <- remDr$findElement(using = 'xpath',
-#'                               value = '//input[@@name = "q"]')
+#'   using = "id",
+#'   value = webElem1$getElementAttribute("id")[[1]]
+#' )
+#' webElem3 <- remDr$findElement(
+#'   using = "xpath",
+#'   value = '//input[@@name = "q"]'
+#' )
 #'
 #' # Enter some text in the search box
 #'
-#' webElem1$sendKeysToElement(list('RSelenium was here'))
+#' webElem1$sendKeysToElement(list("RSelenium was here"))
 #'
 #' # clear the text previously entered
 #'
 #' webElem1$clearElement()
 #'
 #' # show an example of sending a key press
-#' webElem1$sendKeysToElement(list('R', key = 'enter'))
+#' webElem1$sendKeysToElement(list("R", key = "enter"))
 #'
 #' # Collate the results for the `R` search
 #' googLinkText <- remDr$findElements(value = "//h3[@@class = 'r']")
@@ -131,11 +136,15 @@
 #' googLinkDesc <- remDr$findElements(value = "//div[@@class = 's']")
 #' linkDescription <- sapply(googLinkDesc, function(x) x$getElementText())
 #' googLinkHref <- remDr$findElements(value = "//h3[@@class = 'r']/a")
-#' linkHref <- sapply(googLinkHref,
-#'                    function(x) x$getElementAttribute('href'))
+#' linkHref <- sapply(
+#'   googLinkHref,
+#'   function(x) x$getElementAttribute("href")
+#' )
 #'
-#' data.frame(heading = linkHeading,
-#'            description = linkDescription, href = linkHref)
+#' data.frame(
+#'   heading = linkHeading,
+#'   description = linkDescription, href = linkHref
+#' )
 #'
 #' # Example of javascript call
 #' remDr$executeScript("return arguments[0] + arguments[1];", args = 1:2)
@@ -152,13 +161,13 @@
 #' remDr$navigate("http://ariya.github.com/js/random/")
 #' # returns a set of random numbers
 #' remDr$findElement("id", "numbers")$getElementText()[[1]]
-#  # now try injecting a new Math,random function
-#' result = remDr$phantomExecute("var page = this;
+#' #  # now try injecting a new Math,random function
+#' result <- remDr$phantomExecute("var page = this;
 #'                                page.onInitialized = function () {
 #'                                page.evaluate(function () {
 #'                                Math.random = function() {return 42/100}
 #'                                })
-#'                                }", list());
+#'                                }", list())
 #' remDr$navigate("http://ariya.github.com/js/random/")
 #' # Math.random returns our custom function
 #' remDr$findElement("id", "numbers")$getElementText()[[1]]
@@ -186,17 +195,16 @@ remoteDriver <-
     methods = list(
       initialize =
         function(
-          remoteServerAddr = "localhost",
-          port = 4444,
-          browserName = "firefox",
-          path = "/wd/hub",
-          version = "",
-          platform = "ANY",
-          javascript = TRUE,
-          nativeEvents = TRUE,
-          extraCapabilities = list(),
-          ...
-        ) {
+                 remoteServerAddr = "localhost",
+                 port = 4444,
+                 browserName = "firefox",
+                 path = "/wd/hub",
+                 version = "",
+                 platform = "ANY",
+                 javascript = TRUE,
+                 nativeEvents = TRUE,
+                 extraCapabilities = list(),
+                 ...) {
           remoteServerAddr <<- remoteServerAddr
           port <<- port
           browserName <<- browserName
@@ -208,7 +216,7 @@ remoteDriver <-
           extraCapabilities <<- extraCapabilities
           serverURL <<- paste0("http://", remoteServerAddr, ":", port, path)
           callSuper(...)
-          },
+        },
       show = function() {
         print(
           list(
@@ -351,7 +359,7 @@ remoteDriver <-
       },
 
       dismissAlert = function() {
-        "Dismisses the currently displayed alert dialog. For comfirm() and
+        "Dismisses the currently displayed alert dialog. For confirm() and
         prompt() dialogs, this is equivalent to clicking the 'Cancel'
         button. For alert() dialogs, this is equivalent to clicking the
         'OK' button."
@@ -363,11 +371,10 @@ remoteDriver <-
       },
 
       mouseMoveToLocation = function(
-        x = NA_integer_,
-        y = NA_integer_,
-        webElement = NULL
-      ) {
-        "Move the mouse by an offset of the specificed element. If no
+                                     x = NA_integer_,
+                                     y = NA_integer_,
+                                     webElement = NULL) {
+        "Move the mouse by an offset of the specified element. If no
         element is specified, the move is relative to the current mouse
         cursor. If an element is provided but no offset, the mouse will be
         moved to the center of the element. If the element is not visible,
@@ -445,7 +452,8 @@ remoteDriver <-
           serverURL, sessionInfo[["id"]]
         )
         queryRD(
-          qpath, "POST", qdata = list(type = type, ms = milliseconds)
+          qpath, "POST",
+          qdata = list(type = type, ms = milliseconds)
         )
       },
 
@@ -730,7 +738,6 @@ remoteDriver <-
             writeBin(base64_decode(.self$value[[1]]), file)
           }
         }
-
       },
       switchToFrame = function(Id) {
         "Change focus to another frame on the page. Id can be
@@ -772,8 +779,7 @@ remoteDriver <-
           "%s/session/%s/window/%s/position",
           serverURL, sessionInfo[["id"]], winHand
         )
-        queryRD(qpath, "POST", qdata = list(x = x, y = y)
-        )
+        queryRD(qpath, "POST", qdata = list(x = x, y = y))
       },
 
       setWindowSize = function(width, height, winHand = "current") {
@@ -784,7 +790,8 @@ remoteDriver <-
           serverURL, sessionInfo[["id"]], winHand
         )
         queryRD(
-          qpath, "POST", qdata = list(width = width, height = height)
+          qpath, "POST",
+          qdata = list(width = width, height = height)
         )
       },
 
@@ -817,14 +824,13 @@ remoteDriver <-
       },
 
       addCookie = function(
-        name,
-        value,
-        path = "/",
-        domain = NULL,
-        httpOnly = NULL,
-        expiry = NULL,
-        secure = FALSE
-      ) {
+                           name,
+                           value,
+                           path = "/",
+                           domain = NULL,
+                           httpOnly = NULL,
+                           expiry = NULL,
+                           secure = FALSE) {
         "Set a cookie on the domain. The inputs are required apart from
         those with default values."
         cookie <- list(
@@ -874,12 +880,11 @@ remoteDriver <-
       },
 
       findElement = function(
-        using = c(
-          "xpath", "css selector", "id", "name", "tag name", "class name",
-          "link text", "partial link text"
-        ),
-        value
-      ) {
+                             using = c(
+                               "xpath", "css selector", "id", "name", "tag name", "class name",
+                               "link text", "partial link text"
+                             ),
+                             value) {
         "Search for an element on the page, starting from the document
         root. The located element will be returned as an object of
         webElement class.The inputs are:
@@ -924,12 +929,11 @@ remoteDriver <-
       },
 
       findElements = function(
-        using = c(
-          "xpath", "css selector", "id", "name", "tag name", "class name",
-          "link text", "partial link text"
-        ),
-        value
-      ) {
+                              using = c(
+                                "xpath", "css selector", "id", "name", "tag name", "class name",
+                                "link text", "partial link text"
+                              ),
+                              value) {
         "Search for multiple elements on the page, starting from the
         document root. The located elements will be returned as an list of
         objects of class WebElement. The inputs are:
@@ -1032,7 +1036,6 @@ remoteDriver <-
         )
         queryRD(qpath)
         .self$value
-
       },
 
       log = function(type) {
@@ -1071,12 +1074,13 @@ remoteDriver <-
       closeServer = function() {
         "Closes the server in practice terminating the process. This is
         useful for linux systems. On windows the java binary operates as a
-        seperate shell which the user can terminate."
+        separate shell which the user can terminate."
         servURL <- httr::parse_url(serverURL)
         servURL[["path"]] <-
           "/selenium-server/driver/?cmd=shutDownSeleniumServer"
         httr::content(
-          httr::GET(httr::build_url(servURL)), encoding = "UTF-8"
+          httr::GET(httr::build_url(servURL)),
+          encoding = "UTF-8"
         )
       }
     )
