@@ -1,50 +1,56 @@
 context("cookie_tests")
 init <- initFun()
-remDr <- init$remDr; rdBrowser <- init$rdBrowser; loadPage <- init$loadPage
+remDr <- init$remDr
+rdBrowser <- init$rdBrowser
+loadPage <- init$loadPage
 on.exit(remDr$close())
 
 
 test_that("testAddCookie", {
   remDr$navigate(loadPage("simpleTest"))
   remDr$executeScript("return document.cookie;")
-  remDr$addCookie(name=  "foo",
-                  value = "bar")
+  remDr$addCookie(
+    name = "foo",
+    value = "bar"
+  )
   cookie_returned <- remDr$executeScript("return document.cookie;")
   expect_true(grepl("foo=bar", cookie_returned[[1]]))
   remDr$deleteAllCookies()
-}
-)
+})
 
 test_that("testAddingACookieThatExpiredInThePast", {
   remDr$navigate(loadPage("simpleTest"))
-  remDr$addCookie(name=  "foo",
-                  value = "bar",
-                  expiry = as.integer(Sys.time() -100))
+  remDr$addCookie(
+    name = "foo",
+    value = "bar",
+    expiry = as.integer(Sys.time() - 100)
+  )
   cookies <- remDr$getAllCookies()
   expect_equal(length(cookies), 0L)
   remDr$deleteAllCookies()
-}
-)
+})
 
 test_that("testDeleteAllCookie", {
   remDr$navigate(loadPage("simpleTest"))
-  remDr$addCookie(name=  "foo",
-                  value = "bar")
+  remDr$addCookie(
+    name = "foo",
+    value = "bar"
+  )
   remDr$deleteAllCookies()
   expect_equal(0L, length(remDr$getAllCookies()))
   remDr$deleteAllCookies()
-}
-)
+})
 
 test_that("testDeleteCookie", {
   remDr$navigate(loadPage("simpleTest"))
-  remDr$addCookie(name=  "foo",
-                  value = "bar")
+  remDr$addCookie(
+    name = "foo",
+    value = "bar"
+  )
   remDr$deleteCookieNamed(name = "foo")
   expect_equal(0L, length(remDr$getAllCookies()))
   remDr$deleteAllCookies()
-}
-)
+})
 
 test_that("testShouldGetCookieByName", {
   key <- sprintf("key_%d", as.integer(runif(1) * 10000000))
@@ -52,12 +58,11 @@ test_that("testShouldGetCookieByName", {
   remDr$executeScript("document.cookie = arguments[0] + '=set';", list(key))
   cookie <- remDr$getAllCookies()
   expect_equal(
-    cookie[vapply(cookie, "[[", character(1), "name") == key][[1]][["value"]], 
+    cookie[vapply(cookie, "[[", character(1), "name") == key][[1]][["value"]],
     "set"
   )
   remDr$deleteAllCookies()
-}
-)
+})
 
 test_that("testGetAllCookies", {
   key1 <- sprintf("key_%d", as.integer(runif(1) * 10000000))
@@ -70,8 +75,7 @@ test_that("testGetAllCookies", {
   cookies <- remDr$getAllCookies()
   expect_equal(count + 2, length(cookies))
   remDr$deleteAllCookies()
-}
-)
+})
 
 test_that("testShouldNotDeleteCookiesWithASimilarName", {
   cookieOneName <- "fish"
@@ -83,5 +87,4 @@ test_that("testShouldNotDeleteCookiesWithASimilarName", {
   expect_false(identical(cookies[[1]][["name"]], cookieOneName))
   expect_equal(cookies[[1]][["name"]], paste0(cookieOneName, "x"))
   remDr$deleteAllCookies()
-}
-)
+})
