@@ -1,6 +1,8 @@
 context("takes_screenshots_tests")
 init <- initFun()
-remDr <- init$remDr; rdBrowser <- init$rdBrowser; loadPage <- init$loadPage
+remDr <- init$remDr
+rdBrowser <- init$rdBrowser
+loadPage <- init$loadPage
 on.exit(remDr$close())
 
 test_that("testShouldWriteScreenshotToFile", {
@@ -8,8 +10,7 @@ test_that("testShouldWriteScreenshotToFile", {
   result <- remDr$navigate(loadPage("simpleTest"))
   remDr$screenshot(file = tmpF)
   expect_true(file.exists(tmpF))
-}
-)
+})
 
 test_that("test_get_screenshot_as_png", {
   if (!.Platform$OS.type == "unix") {
@@ -20,5 +21,4 @@ test_that("test_get_screenshot_as_png", {
   remDr$screenshot(file = tmpF)
   fileInfo <- system(paste("file --mime-type", tmpF), intern = TRUE)
   expect_true(grepl("image/png", fileInfo))
-}
-)
+})
