@@ -1,6 +1,8 @@
 context("util_function_tests")
 init <- initFun()
-remDr <- init$remDr; rdBrowser <- init$rdBrowser; loadPage <- init$loadPage
+remDr <- init$remDr
+rdBrowser <- init$rdBrowser
+loadPage <- init$loadPage
 selFILE <- ""
 on.exit(remDr$close())
 
@@ -45,12 +47,14 @@ on.exit(remDr$close())
 #       expect_identical(out$getPID(), 100L)
 #       expect_identical(out$stop(), 100L)
 #     }
-#   )  
+#   )
 # }
 # )
 
 test_that("canGetFirefoxProfile", {
-  if(Sys.info()[["sysname"]] != "Linux") return()
+  if (Sys.info()[["sysname"]] != "Linux") {
+    return()
+  }
   out <- getFirefoxProfile(tempdir(), useBase = TRUE)
   expect_identical(names(out), "firefox_profile")
 })
@@ -58,12 +62,15 @@ test_that("canGetFirefoxProfile", {
 test_that("canGetChromeProfile", {
   cprof <- getChromeProfile("a", "b")
   expect_equal(length(cprof[["chromeOptions"]][["args"]]), 2L)
-  expect_identical(cprof[["chromeOptions"]][["args"]][[1]], 
-                   "--user-data-dir=a")
-  expect_identical(cprof[["chromeOptions"]][["args"]][[2]], 
-                   "--profile-directory=b")
-}
-)
+  expect_identical(
+    cprof[["chromeOptions"]][["args"]][[1]],
+    "--user-data-dir=a"
+  )
+  expect_identical(
+    cprof[["chromeOptions"]][["args"]][[2]],
+    "--profile-directory=b"
+  )
+})
 
 # test_that("canStartPhantom", {
 #   if(Sys.info()[["sysname"]] != "Linux") return()
@@ -83,21 +90,20 @@ test_that("canGetChromeProfile", {
 #     },
 #     `tools::pskill` = function(pid, ...){
 #       return(pid)
-#     }, 
+#     },
 #     {
 #       out <- phantom("myphantompath")
 #       expect_identical(out$getPID(), 100L)
 #       expect_identical(out$stop(), 100L)
 #     }
-#     
+#
 #   )
 # })
 
 test_that("canMakeFirefoxProfile", {
-  if(Sys.info()[["sysname"]] != "Linux") return()
+  if (Sys.info()[["sysname"]] != "Linux") {
+    return()
+  }
   fprof <- makeFirefoxProfile(list(browser.download.dir = "D:/temp"))
   expect_identical(names(fprof), "firefox_profile")
-}
-)
-
-
+})
